==> push-2.0.72.3-sources.jar: com/voxeet/push/utils/NotificationHelper.java <==
package com.voxeet.push.utils;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.graphics.Color;
import android.os.Build;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.text.TextUtils;

/**
 * Simple Firebase wrapper
 * <p>
 * Note that when the app is awaken from a killed-state (notifications), don't forget to init it in your
 * own Application override
 * <p>
 * note : in the current version, the isEnabled() method has been renamed to
 * isTokenUploadAllowed(), in a future release it can switch back to its "normal" behaviour
 */
@Annotate
public class NotificationHelper {

    public static final String SDK_CHANNEL_ID = "voxeet_sdk_channel_id";
    public static final String SDK_CHANNEL_NAME = "voxeet_sdk_channel_name";
    public static final String SDK_CHANNEL_DESCRIPTION = "voxeet_sdk_channel_description";
    public static final String SDK_CHANNEL_COLOR = "voxeet_sdk_channel_color";

    public static final String DEFAULT_ID = "VideoConference";
    public static final String DEFAULT_NAME = "Video Conference";
    public static final String DEFAULT_DESCRIPTION = "Incoming calls are managed here";
    public static final int DEFAULT_COLOR = Color.WHITE;

    private static boolean ChannelSet = false;

    private NotificationHelper() {
    }

    public static String getChannelId(@NonNull Context context) {
        return readMetadata(context, SDK_CHANNEL_ID, DEFAULT_ID);
    }

    public static boolean createNotificationChannel(@NonNull Context context) {
        return createNotificationChannel(context,
                readMetadata(context, SDK_CHANNEL_ID, DEFAULT_ID),
                readMetadata(context, SDK_CHANNEL_NAME, DEFAULT_NAME),
                readMetadata(context, SDK_CHANNEL_DESCRIPTION, DEFAULT_DESCRIPTION),
                readMetadataInt(context, SDK_CHANNEL_COLOR, DEFAULT_COLOR));
    }

    public static boolean createNotificationChannel(@NonNull Context context,
                                                    @NonNull String id,
                                                    @NonNull CharSequence name,
                                                    @NonNull String description,
                                                    int argb) {
        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.O) {
            return true;
        } else {
            if (ChannelSet) return false;
            NotificationManager mNotificationManager = (NotificationManager) context.getSystemService(Context.NOTIFICATION_SERVICE);

            int importance = NotificationManager.IMPORTANCE_HIGH;

            NotificationChannel channel = new NotificationChannel(id, name, importance);
            channel.setDescription(description);
            channel.enableLights(true);
            channel.setLightColor(argb);

            channel.enableVibration(true);
            channel.setVibrationPattern(new long[]{100, 200});
            channel.setLockscreenVisibility(Notification.VISIBILITY_PRIVATE);

            if (null != mNotificationManager) {
                mNotificationManager.createNotificationChannel(channel);
                ChannelSet = true;
            }
            return true;
        }
    }

    private static int readMetadataInt(@NonNull Context context, @NonNull String key, int argb) {
        try {
            String metaData = readMetadata(context, key, null);
            if (!TextUtils.isEmpty(metaData)) return Integer.parseInt(metaData);
        } catch (Exception e) {

        }
        return argb;
    }

    private static String readMetadata(@NonNull Context context, @NonNull String key, @NonNull String def) {
        ApplicationInfo appInfo = null;
        try {
            appInfo = context.getPackageManager().getApplicationInfo(context.getPackageName(),
                    PackageManager.GET_META_DATA);
            Bundle bundle = appInfo.metaData;
            String value = bundle.getString(key);
            if (!TextUtils.isEmpty(value)) return value;
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        return def;
    }
}

==> push-2.0.73.15-sources.jar: com/voxeet/push/utils/NotificationHelper.java <==
package com.voxeet.push.utils;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.graphics.Color;
import android.os.Build;
import android.os.Bundle;
import android.support.annotation.NonNull;
import android.text.TextUtils;

/**
 * The NotificationHelper model is a simple firebase wrapper that initializes the application when it is awoken from the killed state. It gets the [firebase channel ID](/documentation/sdk/reference/android/models/notificationhelper#getchannelid) and [creates](/documentation/sdk/reference/android/models/notificationhelper#createNotificationChannel) notification channels.
 *
 * Note: In the current version, the `isEnabled()` method is renamed to `isTokenUploadAllowed()`. In future releases, it can be switched back to the previous behavior.
 *
 * _Note : in the current version, the `isEnabled()` method is renamed to `isTokenUploadAllowed()`. In a future release, it can switch back to "normal" behavior._
 */
@Annotate
public class NotificationHelper {

    public static final String SDK_CHANNEL_ID = "voxeet_sdk_channel_id";
    public static final String SDK_CHANNEL_NAME = "voxeet_sdk_channel_name";
    public static final String SDK_CHANNEL_DESCRIPTION = "voxeet_sdk_channel_description";
    public static final String SDK_CHANNEL_COLOR = "voxeet_sdk_channel_color";

    public static final String DEFAULT_ID = "VideoConference";
    public static final String DEFAULT_NAME = "Video Conference";
    public static final String DEFAULT_DESCRIPTION = "Incoming calls are managed here";
    public static final int DEFAULT_COLOR = Color.WHITE;

    private static boolean ChannelSet = false;

    private NotificationHelper() {
    }

    /**
     * Gets the Firebase channel ID.
     * @param context The application context.
     * @return  The channel ID for Voxeet notifications.
     */
    public static String getChannelId(@NonNull Context context) {
        return readMetadata(context, SDK_CHANNEL_ID, DEFAULT_ID);
    }

    /**
     * Helps to create the Voxeet default channel. It is used because Firebase and Android require applications to have their own valid notification channels.
     *
     * @param context The context that will be manipulated to create the channel.
     * @return a flag indicating if the channel is set properly. A false value informs that this method was already called for the Android version where it's mandatory. Android versions prior to Android O always return a true value.
     */
    public static boolean createNotificationChannel(@NonNull Context context) {
        return createNotificationChannel(context,
                readMetadata(context, SDK_CHANNEL_ID, DEFAULT_ID),
                readMetadata(context, SDK_CHANNEL_NAME, DEFAULT_NAME),
                readMetadata(context, SDK_CHANNEL_DESCRIPTION, DEFAULT_DESCRIPTION),
                readMetadataInt(context, SDK_CHANNEL_COLOR, DEFAULT_COLOR));
    }

    /**
     * Creates the notification channel because Firebase and Android require applications to have their own valid notification channels.
     *
     * @param context The context that will be manipulated to create the channel.
     * @param id The channel ID.
     * @param name The displayed name of the channel (to be translated).
     * @param description The description of the channel (to be translated).
     * @param argb The color of the notifications in the 0xaarrggbb representation.
     * @return a flag indicating if the channel is set up properly. A false value informs that this method was already called for the Android version where it is mandatory. Android versions prior to Android O always return a true value.
     */
    public static boolean createNotificationChannel(@NonNull Context context,
                                                    @NonNull String id,
                                                    @NonNull CharSequence name,
                                                    @NonNull String description,
                                                    int argb) {
        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.O) {
            return true;
        } else {
            if (ChannelSet) return false;
            NotificationManager mNotificationManager = (NotificationManager) context.getSystemService(Context.NOTIFICATION_SERVICE);

            int importance = NotificationManager.IMPORTANCE_HIGH;

            NotificationChannel channel = new NotificationChannel(id, name, importance);
            channel.setDescription(description);
            channel.enableLights(true);
            channel.setLightColor(argb);

            channel.enableVibration(true);
            channel.setVibrationPattern(new long[]{100, 200});
            channel.setLockscreenVisibility(Notification.VISIBILITY_PRIVATE);

            if (null != mNotificationManager) {
                mNotificationManager.createNotificationChannel(channel);
                ChannelSet = true;
            }
            return true;
        }
    }

    private static int readMetadataInt(@NonNull Context context, @NonNull String key, int argb) {
        try {
            String metaData = readMetadata(context, key, null);
            if (!TextUtils.isEmpty(metaData)) return Integer.parseInt(metaData);
        } catch (Exception e) {

        }
        return argb;
    }

    private static String readMetadata(@NonNull Context context, @NonNull String key, @NonNull String def) {
        ApplicationInfo appInfo = null;
        try {
            appInfo = context.getPackageManager().getApplicationInfo(context.getPackageName(),
                    PackageManager.GET_META_DATA);
            Bundle bundle = appInfo.metaData;
            String value = bundle.getString(key);
            if (!TextUtils.isEmpty(value)) return value;
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
        return def;
    }
}
